==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Rozliczenie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Rozliczenie extends GenericDPSObject {
    /**
     * ROZLICZENIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ROZLICZENIE.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mieszkaniecId;

    /**
     * ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikWykonalId;

    /**
     * ROZLICZENIE.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * ROZLICZENIE.DATA_WYKONANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWykonania;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ROZLICZENIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ROZLICZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ROZLICZENIE.MIESZKANIEC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * ROZLICZENIE.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikWykonalId() {
        return pracownikWykonalId;
    }

    /**
     * ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     *
     * @param pracownikWykonalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikWykonalId(Long pracownikWykonalId) {
        this.pracownikWykonalId = pracownikWykonalId;
    }

    /**
     * @return ROZLICZENIE.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * ROZLICZENIE.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ROZLICZENIE.DATA_WYKONANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWykonania() {
        return dataWykonania;
    }

    /**
     * ROZLICZENIE.DATA_WYKONANIA
     *
     * @param dataWykonania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWykonania(Date dataWykonania) {
        this.dataWykonania = dataWykonania;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Rozliczenie other = (Rozliczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getPracownikWykonalId() == null ? other.getPracownikWykonalId() == null : this.getPracownikWykonalId().equals(other.getPracownikWykonalId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataWykonania() == null ? other.getDataWykonania() == null : this.getDataWykonania().equals(other.getDataWykonania()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getPracownikWykonalId() == null) ? 0 : getPracownikWykonalId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataWykonania() == null) ? 0 : getDataWykonania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", pracownikWykonalId=").append(pracownikWykonalId);
        sb.append(", data=").append(data);
        sb.append(", dataWykonania=").append(dataWykonania);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Rozliczenie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Rozliczenie extends GenericDPSObject {
    /**
     * ROZLICZENIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ROZLICZENIE.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mieszkaniecId;

    /**
     * ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikWykonalId;

    /**
     * ROZLICZENIE.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * ROZLICZENIE.DATA_WYKONANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWykonania;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ROZLICZENIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ROZLICZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ROZLICZENIE.MIESZKANIEC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * ROZLICZENIE.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikWykonalId() {
        return pracownikWykonalId;
    }

    /**
     * ROZLICZENIE.PRACOWNIK_WYKONAL_ID
     *
     * @param pracownikWykonalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikWykonalId(Long pracownikWykonalId) {
        this.pracownikWykonalId = pracownikWykonalId;
    }

    /**
     * @return ROZLICZENIE.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * ROZLICZENIE.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ROZLICZENIE.DATA_WYKONANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWykonania() {
        return dataWykonania;
    }

    /**
     * ROZLICZENIE.DATA_WYKONANIA
     *
     * @param dataWykonania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWykonania(Date dataWykonania) {
        this.dataWykonania = dataWykonania;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Rozliczenie other = (Rozliczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getPracownikWykonalId() == null ? other.getPracownikWykonalId() == null : this.getPracownikWykonalId().equals(other.getPracownikWykonalId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataWykonania() == null ? other.getDataWykonania() == null : this.getDataWykonania().equals(other.getDataWykonania()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getPracownikWykonalId() == null) ? 0 : getPracownikWykonalId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataWykonania() == null) ? 0 : getDataWykonania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", pracownikWykonalId=").append(pracownikWykonalId);
        sb.append(", data=").append(data);
        sb.append(", dataWykonania=").append(dataWykonania);
        sb.append("]");
        return sb.toString();
    }
}
